# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-Class-Inspector
Version:	1.36
Release:	13.%{__distinit}%{__distvers}
Summary:	Get information about a class and its structure
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/Class-Inspector
Source0:	https://cpan.metacpan.org/modules/by-module/Class/Class-Inspector-%{version}.tar.gz
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module Runtime
BuildRequires:	perl(base)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(strict)
BuildRequires:	perl(utf8)
BuildRequires:	perl(vars)
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(Config)
BuildRequires:	perl(constant)
BuildRequires:	perl(Test::More) >= 0.98
# Optional Tests
BuildRequires:	perl(Devel::Hide)
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif
Requires:	perl(utf8)

%description
Class::Inspector allows you to get information about a loaded class.
Most or all of this information can be found in other ways, but they aren't
always very friendly, and usually involve a relatively high level of Perl
wizardry, or strange and unusual looking code. Class::Inspector attempts to
provide an easier, more friendly interface to this information.

%prep
%setup -q -n Class-Inspector-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test

%files
%license LICENSE
%doc Changes README
%{perl_vendorlib}/Class/
%{_mandir}/man3/Class::Inspector.3*
%{_mandir}/man3/Class::Inspector::Functions.3*

%changelog
* Fri Jul 14 2023 Paul Howarth <paul@city-fan.org> - 1.36-13
- Use SPDX-format license tag
- Use %%license unconditionally

* Sun Jul 21 2019 Paul Howarth <paul@city-fan.org> - 1.36-1
- Update to 1.36
  - Fix bug in methods method that could cause it to modify @ISA (GH#11)

* Fri Mar 29 2019 Paul Howarth <paul@city-fan.org> - 1.34-1
- Update to 1.34
  - Fix compatibility with Devel::Hide (GH#6, GH#8)
- Switch upstream from search.cpan.org to metacpan.org

* Wed Aug  9 2017 Paul Howarth <paul@city-fan.org> - 1.32-1
- Update to 1.32
  - The installed method now supports @INC hooks of any type (coderef was
    supported as of 1.29, now arrayrefs and objects are also supported)
  - Detect probably broken Perl on Cygwin in Makefile.PL (see GH#5)
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section

* Sat Nov 26 2016 Paul Howarth <paul@city-fan.org> - 1.31-1
- Update to 1.31
  - Migrated from Module::Install to Dist::Zilla and ExtUtils::MakeMaker
  - Fixed meta for repository, which was pointing to the wrong URL

* Wed Nov 23 2016 Paul Howarth <paul@city-fan.org> - 1.30-1
- Update to 1.30
  - Fix Makefile.PL to work with Perls without '.' in @INC
  - Fix for the installed method when used with a PAR archive (CPAN RT#42846)
  - Minor documentation fixes (grammar, spelling: CPAN RT#74481, CPAN RT#85356)
  - Update metadata to point to github repository, plus some other minor dist
    meta tweaks
- This release by PLICEASE → update source URL
- Extra tests no longer shipped, so don't try to run them
- Upstream dropped LICENSE and README files

* Tue Aug  9 2016 Paul Howarth <paul@city-fan.org> - 1.28-15
- Classify buildreqs by usage
- Simplify find command using -delete

* Mon Sep  1 2014 Paul Howarth <paul@city-fan.org> - 1.28-7
- Drop %%defattr, redundant since rpm 4.4
- Use %%license where possible

* Mon Oct 22 2012 Paul Howarth <paul@city-fan.org> - 1.28-1
- Update to 1.28
  - No functional changes
  - Updating to Module::Install::DSL 1.06

* Mon Jul 16 2012 Paul Howarth <paul@city-fan.org> - 1.27-4
- Perl 5.16 post-bootstrap rebuild

* Sun Jul  1 2012 Paul Howarth <paul@city-fan.org> - 1.27-3
- BR: perl(constant), perl(Cwd) and perl(File::Path)
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Tue Feb  7 2012 Paul Howarth <paul@city-fan.org> - 1.27-2
- Don't BR: perl(Test::MinimumVersion) if we're bootstrapping

* Wed Jan 25 2012 Paul Howarth <paul@city-fan.org> - 1.27-1
- Update to 1.27
  - Update to Module::Install::DSL 1.04
  - Update copyright year
  - Remove usage of defined @{"X::ISA"} to avoid warnings in 5.15.7 onwards
- BR: perl(Exporter) and perl(File::Spec)
- Explicitly run the release tests
- Install to vendor dirs rather than perl dirs

* Wed Jun 22 2011 Paul Howarth <paul@city-fan.org> - 1.25-2
- Rebuild for perl 5.14.1 in Rawhide
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Thu Jan 27 2011 Paul Howarth <paul@city-fan.org> - 1.25-1
- Update to 1.25
  - Update to Module::Install::DSL 1.00
  - Update copyright year
- Install to perl dirs rather than vendor dirs

* Fri Jun 25 2010 Paul Howarth <paul@city-fan.org> - 1.24-4
- Rebuild for perl 5.12.1 in Rawhide

* Tue Jun  8 2010 Paul Howarth <paul@city-fan.org> - 1.24-3
- Fix dist tag for RHEL-6 Beta

* Fri Feb 19 2010 Paul Howarth <paul@city-fan.org> - 1.24-2
- Dist tag for Rawhide no longer needs special-casing
- Use %%{_fixperms} macro instead of our own %%{__chmod} incantation

* Wed Apr 22 2009 Paul Howarth <paul@city-fan.org> - 1.24-1
- Update to 1.24 (add the Class::Inspector::Functions interface)
- Include manpage for Class::Inspector::Functions
- Reinstate buildreqs perl(Test::CPAN::Meta) and perl(Test::MinimumVersion)

* Wed Sep  3 2008 Paul Howarth <paul@city-fan.org> - 1.23-2
- Import from Fedora
- Drop perl(Test::CPAN::Meta) buildreq for now
- Drop perl(Test::MinimumVersion) buildreq, which seems to cause a bogus
  failure in t/pmv.t on RHL9
- Add buildreq perl(ExtUtils::MakeMaker)

* Tue Jun 10 2008 Ralf Corsépius <rc040203@freenet.de> - 1.23-1
- Upstream update

* Tue Mar 11 2008 Ralf Corsépius <rc040203@freenet.de> - 1.22-1
- Upstream update

* Thu Feb 28 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 1.20-3
- Rebuild normally, second pass

* Wed Feb 27 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 1.20-2
- Rebuild for perl 5.10 (again), first pass

* Thu Feb 14 2008 Ralf Corsépius <rc040203@freenet.de> - 1.20-1
- Upstream update

* Mon Jan 14 2008 Tom "spot" Callaway <tcallawa@redhat.com> 1.18-3
- rebuild normally, second pass

* Sun Jan 13 2008 Tom "spot" Callaway <tcallawa@redhat.com> 1.18-2.1
- rebuild for new perl, first pass, disable TMV, tests

* Sun Nov 25 2007 Ralf Corsépius <rc040203@freenet.de> - 1.18-2
- Add BR: perl(Test::MinimumVersion)

* Tue Nov 20 2007 Ralf Corsépius <rc040203@freenet.de> - 1.18-1
- Upstream update

* Fri Aug 17 2007 Ralf Corsépius <rc040203@freenet.de> - 1.17-1
- Upstream update

* Thu Apr 19 2007 Ralf Corsépius <rc040203@freenet.de> - 1.16-3
- Reflect perl package split

* Tue Sep 05 2006 Ralf Corsépius <rc040203@freenet.de> - 1.16-2
- Mass rebuild

* Sun May 21 2006 Ralf Corsépius <rc040203@freenet.de> - 1.16-1
- Upstream update

* Mon May 08 2006 Ralf Corsépius <rc040203@freenet.de> - 1.15-1
- Upstream update

* Wed Mar 01 2006 Ralf Corsépius <rc040203@freenet.de> - 1.13-2
- Rebuild for perl-5.8.8

* Thu Sep 29 2005 Ralf Corsepius <rc040203@freenet.de> - 1.13-1
- Upstream update

* Tue Sep 13 2005 Ralf Corsepius <rc040203@freenet.de>
- Fix another typo in %%summary

* Tue Sep 13 2005 Ralf Corsepius <rc040203@freenet.de> - 1.12-2
- Fix typo in %%summary
- Spec file cleanup

* Tue Sep 13 2005 Ralf Corsepius <rc040203@freenet.de> - 1.12-1
- FE submission
